@@ -130,7 +130,6 @@ class PythonFramworkBaseClass(getNewOriginalModel()):
     def onPersistentToTransient(self, session):
         self.onChange(session, eventType=OnORMChangeEventType.PERSISTENT_TO_TRANSIENT)
 
-
 @Function
 def getNewModel():
     return declarative_base(cls=PythonFramworkBaseClass, name='PythonFramworkBaseClass')
@@ -434,6 +433,12 @@ class SqlAlchemyProxy:
         self.session.commit()
         return self.onChange(instance)
 
+    @Method
+    def findAllByIdInAndCommit(self, idList):
+        instanceList = self.repository.session.query(self.model).filter(self.model.id.in_(idList)).all()
+        self.repository.session.commit()
+        return self.onChange(instanceList)
+
     @Method
     def existsByIdAndCommit(self, id, modelClass):
         # ret = Session.query(exists().where(and_(Someobject.field1 == value1, Someobject.field2 == value2)))
@@ -447,6 +452,12 @@ class SqlAlchemyProxy:
         self.session.commit()
         return self.onChange(instance)
 
+    @Method
+    def findAllByKeyInAndCommit(self, keyList):
+        instanceList = self.repository.session.query(self.model).filter(self.model.key.in_(keyList)).all()
+        self.repository.session.commit()
+        return self.onChange(instanceList)
+
     @Method
     def existsByKeyAndCommit(self, key, modelClass):
         objectExists = self.session.query(exists().where(modelClass.key == key)).one()[0]
@@ -459,6 +470,12 @@ class SqlAlchemyProxy:
         self.session.commit()
         return self.onChange(instance)
 
+    @Method
+    def findAllByStatusInAndCommit(self, statusList):
+        instanceList = self.repository.session.query(self.model).filter(self.model.status.in_(statusList)).all()
+        self.repository.session.commit()
+        return self.onChange(instanceList)
+
     @Method
     def existsByQueryAndCommit(self, query, modelClass):
         exists = self.session.query(literal(True)).filter(self.session.query(modelClass).filter_by(**query).exists()).scalar()
